@@ -1,5 +1,7 @@
 import re
 
+import dns.resolver
+
 
 def prepare_domain_name(host_in):
     host = re.sub(r'https?://', '', host_in)
@@ -15,3 +17,12 @@ def process_subtake_output(is_valid, line, check, inverse, strict):
     else:
         (_, target) = parts[1:-2].split(': ')
     check(is_valid, domain, target, inverse, strict)
+
+
+def resolve_cname(hostname):
+    cnames = dns.resolver.resolve(hostname, 'CNAME')
+
+    if len(cnames) == 0:
+        raise ResourceWarning("CNAME not found")
+    else:
+        return prepare_domain_name(str(cnames[0]))
